@@ -2,6 +2,5 @@ from selenium.webdriver.common.keys import Keys
 from selenium.webdriver.support import expected_conditions
 from seleniumactions.elements import FluentFinder, Locator, Using
 from seleniumactions.actions import Actions
-from seleniumactions.assertions import assert_condition
-from seleniumactions.conditions import LocatorExists, XpathExists
+from seleniumactions.conditions import LocatorExists
 from seleniumactions.pages import Page
